import { h } from "@stencil/core";
export class ACEFieldComponent {
    constructor() {
        this.error = "";
        this.suppressError = this.suppressError.bind(this);
    }
    /*Show tooltip only if it's set on declaration*/
    showTooltip() {
        if (this.tooltip && this.tooltip != '' && this.error === "")
            return h("span", { class: "tooltiptext" }, this.tooltip);
    }
    keyup(e) {
        console.log('e', e);
        if (this.input)
            this.input.emit(e.target.value);
    }
    suppressError(e) {
        this.error = (this.invalid) ? this.invalid : e.target.validationMessage;
        e.preventDefault();
    }
    rerender() {
        this.render();
    }
    showRequiredInput() {
        return (this.required) ? (h("div", null,
            h("label", null,
                this.label,
                "*"),
            h("input", { type: this.type, placeholder: this.placeholder, class: "form-control", onKeyUp: this.keyup, onInvalid: this.suppressError, required: true }))) :
            (h("div", null,
                h("label", null, this.label),
                h("input", { type: this.type, placeholder: this.placeholder, class: "form-control", onKeyUp: this.keyup })));
    }
    render() {
        return (h("div", null,
            h("div", { class: "mb-3 col-lg-12 col-md-12 col-sm-12 col-xs-10" },
                h("div", { class: "form-input" },
                    this.showRequiredInput(),
                    this.showTooltip(),
                    h("p", { class: "input-hint" }, this.hint),
                    h("div", { class: "invalid-feedbacks" },
                        h("p", null, this.error))))));
    }
    static get is() { return "ace-field"; }
    static get originalStyleUrls() { return {
        "$": ["ace-field.css"]
    }; }
    static get styleUrls() { return {
        "$": ["ace-field.css"]
    }; }
    static get properties() { return {
        "text": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "text",
            "reflect": false
        },
        "columns": {
            "type": "unknown",
            "mutable": false,
            "complexType": {
                "original": "string[]",
                "resolved": "string[]",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            }
        },
        "className": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "class-name",
            "reflect": false
        },
        "placeholder": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "placeholder",
            "reflect": false
        },
        "tooltip": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "tooltip",
            "reflect": false
        },
        "selector": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "selector",
            "reflect": false
        },
        "invalid": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "invalid",
            "reflect": false
        },
        "label": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "label",
            "reflect": false
        },
        "hint": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "hint",
            "reflect": false
        },
        "required": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "required",
            "reflect": false
        },
        "type": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "type",
            "reflect": false
        }
    }; }
    static get states() { return {
        "error": {}
    }; }
    static get events() { return [{
            "method": "input",
            "name": "input",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": ""
            },
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            }
        }]; }
}
