import { h } from "@stencil/core";
export class ACEHeaderComponent {
    constructor() {
        this.logo = "/images/logo.png";
        this.logoUrl = '';
        this.universalLinks = [
            {
                name: 'Home',
                icon: 'fa fa-home',
                url: '/'
            }
        ];
        this.loggedOutLinks = [
            {
                name: 'Blog',
                icon: '',
                url: 'https://blog.ace.fan',
                class: 'default'
            },
            {
                name: 'Support',
                icon: '',
                url: 'mailto:support@ace.fan',
                class: 'default'
            },
            {
                name: 'Log In',
                icon: '',
                url: 'https://login.ace.fan',
                class: 'default'
            },
            {
                name: 'Sign Up',
                icon: '',
                url: 'https://login.ace.fan/signup',
                class: 'selected'
            }
        ];
        this.loggedInLinks = [
            {
                name: 'Buy/Sell',
                icon: 'fa fa-exchange-alt',
                url: `/markets/${this.getCookie("market_id")}`,
                class: 'default' //this is a hack, but it works
            },
            {
                name: 'Wallets',
                icon: 'fa fa-wallet',
                url: '/wallets',
                class: 'default'
            },
            {
                name: 'Transaction History',
                icon: 'fa fa-history',
                url: '/history/orders',
                class: 'default'
            },
            {
                name: 'Support',
                icon: 'fa fa-life-ring',
                url: 'mailto:support@ace.fan',
                class: 'default'
            }
        ];
    }
    componentWillLoad() {
        const cookie = this.getCookie("_ace_session");
        this.isLoggedIn = cookie != null && cookie !== "";
        this.logoUrl = (this.isLoggedIn) ? "/settings" : "/";
    }
    isActive(url) {
        return window.location.href.indexOf(url) !== -1;
    }
    links() {
        //concat the universal links with either the loggedIn or loggedOut links W
        return ((this.isLoggedIn === true) ? this.loggedInLinks : this.loggedOutLinks)
            .map(link => {
            return h("li", { class: `nav-item ${(this.isActive(link.url)) ? 'active' : ''} ${link.class}` },
                h("a", { class: "nav-link", target: "", href: link.url },
                    h("i", { class: link.icon }),
                    h("span", { class: "nav-title" }, link.name)));
        });
    }
    dropdown() {
        return (this.isLoggedIn === true) ?
            h("li", { class: "nav-item dropdown" },
                h("a", { class: "nav-link dropdown-toggle", id: "userDropDown", href: "#", "data-toggle": "dropdown", "aria-haspopup": "true", "aria-expanded": "false" },
                    h("i", { class: "fa fa-user" })),
                h("div", { class: "dropdown-menu", "aria-labelledby": "userDropDown" },
                    h("a", { class: "dropdown-item", href: "/settings" },
                        h("i", { class: "fa fa-user" }),
                        h("span", { class: "nav-title" }, "My Profile")),
                    h("a", { class: "dropdown-item", href: "/logout" },
                        h("i", { class: "fa fa-power-off" }),
                        h("span", { class: "nav-title" }, "Log out"))))
            : '';
    }
    getCookie(cookie) {
        const tmp = (!document || !document.cookie || document.cookie == '') ? null : document.cookie.split(";").map(c => {
            let tmp = c.replace(" ", "").split("="), key = tmp[0], value = tmp[1];
            let temp = {};
            temp[key] = value;
            return temp;
        }).filter(c => c[cookie] != null)[0];
        return (tmp != null) ? tmp[cookie] : null;
    }
    render() {
        return (h("nav", { class: "navbar navbar-expand-lg navbar-dark" },
            h("div", { class: "container" },
                h("a", { class: "text-left navbar-brand", href: "/" },
                    h("img", { class: "logo", src: this.logo })),
                h("button", { class: "navbar-toggler hidden-lg-up", type: "button", "data-toggle": "collapse", "data-target": "#navbarsDefault", "aria-controls": "navbarsDefault", "aria-expanded": "false", "aria-label": "Toggle navigation" },
                    h("span", { class: "navbar-toggler-icon" })),
                h("div", { class: "collapse navbar-collapse", id: "navbarsDefault" },
                    h("ul", { class: "navbar-nav ml-auto" },
                        h("slot", null))))));
    }
    static get is() { return "ace-header"; }
    static get originalStyleUrls() { return {
        "$": ["ace-header.css"]
    }; }
    static get styleUrls() { return {
        "$": ["ace-header.css"]
    }; }
    static get properties() { return {
        "logo": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "logo",
            "reflect": false,
            "defaultValue": "\"/images/logo.png\""
        }
    }; }
}
