import { h } from "@stencil/core";
export class ACETableComponent {
    constructor() {
        this.heading = "Heading";
        this.Data = [];
        //pagination
        this.currentPage = 1;
        this.goToNextPage = this.goToNextPage.bind(this);
        this.goToPreviousPage = this.goToPreviousPage.bind(this);
        this.goToLastPage = this.goToLastPage.bind(this);
        this.goToFirstPage = this.goToFirstPage.bind(this);
        if (!this.perPage)
            this.perPage = 1;
    }
    paginate(array, pageSize, pageNumber) {
        --pageNumber; // because pages logically start with 1, but technically with 0
        return array.slice(pageNumber * pageSize, (pageNumber + 1) * pageSize);
    }
    currentPageHandler() {
        this.initTable();
    }
    handleHeading(newHeading) {
        this.heading = newHeading;
    }
    setPaginationValues() {
        this.totalPages = (this.Data.length / this.perPage);
    }
    setData(newData) {
        this.initTable(newData);
    }
    printLabels() {
        //Gets columns as set
        return (!this.Columns || this.Columns.length == 0) ? "" : this.Columns.map(column => column.label).map(label => h("td", null, label));
    }
    printRows() {
        //Returns the data corresponding to the columns per row
        return (!this.Data || this.Data.length == 0) ? "" : this.Data.map(row => h("tr", null, this.Columns.map(column => {
            return (column.linkable && row.link) ? h("td", null,
                h("a", { href: row.link }, row[column.field])) : h("td", null, row[column.field]);
        })));
    }
    initTable(newData = null) {
        if (!newData)
            this.Data = this.paginate(((typeof this.data === "string") ? this.Data = JSON.parse(this.data) : this.data), this.perPage, this.currentPage);
        else
            this.Data = this.paginate(((typeof newData === "string") ? this.Data = JSON.parse(newData) : newData), this.perPage, this.currentPage);
        this.Columns = JSON.parse(this.columns);
        this.setPaginationValues();
        this.render();
    }
    componentWillLoad() {
        // if(this.data) this.setData(this.data);
        // if(this.Columns) this.setColumns(this.Columns);
        this.initTable();
    }
    goToNextPage() {
        if (this.currentPage < this.totalPages)
            ++this.currentPage;
        this.initTable();
    }
    goToPreviousPage() {
        --this.currentPage;
    }
    goToLastPage() {
        this.currentPage = this.totalPages;
    }
    goToFirstPage() {
        this.currentPage = 1;
    }
    printStartButton() {
        let disabledClass = '';
        if (this.currentPage === 1)
            disabledClass = 'disabled';
        return h("li", { onClick: this.goToFirstPage },
            h("a", { class: disabledClass }, "Start"));
    }
    printPreviousButton() {
        let disabledClass = '';
        if (this.currentPage <= 1)
            disabledClass = 'disabled';
        return h("li", { class: disabledClass, onClick: this.goToPreviousPage },
            h("a", null,
                h("i", { class: "fas fa-chevron-circle-left" })));
    }
    printNextButton() {
        let disabledClass = '';
        if (this.currentPage >= this.totalPages)
            disabledClass = 'disabled';
        return h("li", { onClick: this.goToNextPage, class: disabledClass },
            h("a", null,
                h("i", { class: "fas fa-chevron-circle-right" })));
    }
    printEndButton() {
        let disabledClass = '';
        if (this.currentPage >= this.totalPages)
            disabledClass = 'disabled';
        return h("li", { class: disabledClass, onClick: this.goToLastPage },
            h("a", null, "End"));
    }
    render() {
        return (h("div", { class: "acetable" },
            h("div", { class: "tableheading" },
                h("p", { class: "tableheading-text" }, this.heading)),
            h("div", { class: "table-responsive" },
                h("table", { class: "table table-striped table-hover table-condensed" },
                    h("thead", { class: "thead-inverse" },
                        h("tr", null, this.printLabels())),
                    h("tbody", null, this.printRows()))),
            h("div", { class: "tablefooter" },
                h("ul", { class: "pagination" },
                    this.printStartButton(),
                    this.printPreviousButton(),
                    h("li", { class: "active" },
                        h("a", { href: "#" },
                            " ",
                            this.currentPage,
                            " ")),
                    this.printNextButton(),
                    this.printEndButton()))));
    }
    static get is() { return "ace-table"; }
    static get originalStyleUrls() { return {
        "$": ["ace-table.css"]
    }; }
    static get styleUrls() { return {
        "$": ["ace-table.css"]
    }; }
    static get properties() { return {
        "heading": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "heading",
            "reflect": true,
            "defaultValue": "\"Heading\""
        },
        "columns": {
            "type": "any",
            "mutable": false,
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "columns",
            "reflect": true
        },
        "data": {
            "type": "any",
            "mutable": false,
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "data",
            "reflect": true
        },
        "perPage": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "per-page",
            "reflect": true
        }
    }; }
    static get states() { return {
        "Data": {},
        "currentPage": {}
    }; }
    static get watchers() { return [{
            "propName": "currentPage",
            "methodName": "currentPageHandler"
        }, {
            "propName": "heading",
            "methodName": "handleHeading"
        }, {
            "propName": "data",
            "methodName": "setData"
        }]; }
}
